@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     AttributeTypeType,
@@ -21,6 +21,7 @@ from .literals import (
     DomainType,
     EvaluationTypeType,
     FilterConditionStringType,
+    OptimizationMetricType,
     ScalingTypeType,
 )
 
@@ -136,7 +137,7 @@ CategoricalParameterRangeTypeDef = TypedDict(
     "CategoricalParameterRangeTypeDef",
     {
         "Name": str,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 
@@ -173,8 +174,8 @@ _RequiredCreateDatasetGroupRequestRequestTypeDef = TypedDict(
 _OptionalCreateDatasetGroupRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDatasetGroupRequestRequestTypeDef",
     {
-        "DatasetArns": List[str],
-        "Tags": List["TagTypeDef"],
+        "DatasetArns": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -210,7 +211,7 @@ _OptionalCreateDatasetImportJobRequestRequestTypeDef = TypedDict(
         "TimeZone": str,
         "UseGeolocationForTimeZone": bool,
         "GeolocationFormat": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -245,7 +246,7 @@ _OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
     {
         "DataFrequency": str,
         "EncryptionConfig": "EncryptionConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -276,7 +277,7 @@ _RequiredCreateForecastExportJobRequestRequestTypeDef = TypedDict(
 _OptionalCreateForecastExportJobRequestRequestTypeDef = TypedDict(
     "_OptionalCreateForecastExportJobRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -307,8 +308,8 @@ _RequiredCreateForecastRequestRequestTypeDef = TypedDict(
 _OptionalCreateForecastRequestRequestTypeDef = TypedDict(
     "_OptionalCreateForecastRequestRequestTypeDef",
     {
-        "ForecastTypes": List[str],
-        "Tags": List["TagTypeDef"],
+        "ForecastTypes": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -339,7 +340,7 @@ _RequiredCreatePredictorBacktestExportJobRequestRequestTypeDef = TypedDict(
 _OptionalCreatePredictorBacktestExportJobRequestRequestTypeDef = TypedDict(
     "_OptionalCreatePredictorBacktestExportJobRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -373,15 +374,16 @@ _OptionalCreatePredictorRequestRequestTypeDef = TypedDict(
     "_OptionalCreatePredictorRequestRequestTypeDef",
     {
         "AlgorithmArn": str,
-        "ForecastTypes": List[str],
+        "ForecastTypes": Sequence[str],
         "PerformAutoML": bool,
         "AutoMLOverrideStrategy": Literal["LatencyOptimized"],
         "PerformHPO": bool,
-        "TrainingParameters": Dict[str, str],
+        "TrainingParameters": Mapping[str, str],
         "EvaluationParameters": "EvaluationParametersTypeDef",
         "HPOConfig": "HyperParameterTuningJobConfigTypeDef",
         "EncryptionConfig": "EncryptionConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
+        "OptimizationMetric": OptimizationMetricType,
     },
     total=False,
 )
@@ -683,6 +685,7 @@ DescribePredictorResponseTypeDef = TypedDict(
         "Message": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "OptimizationMetric": OptimizationMetricType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -701,6 +704,8 @@ ErrorMetricTypeDef = TypedDict(
         "ForecastType": str,
         "WAPE": float,
         "RMSE": float,
+        "MASE": float,
+        "MAPE": float,
     },
     total=False,
 )
@@ -732,8 +737,8 @@ _RequiredFeaturizationConfigTypeDef = TypedDict(
 _OptionalFeaturizationConfigTypeDef = TypedDict(
     "_OptionalFeaturizationConfigTypeDef",
     {
-        "ForecastDimensions": List[str],
-        "Featurizations": List["FeaturizationTypeDef"],
+        "ForecastDimensions": Sequence[str],
+        "Featurizations": Sequence["FeaturizationTypeDef"],
     },
     total=False,
 )
@@ -754,7 +759,7 @@ _RequiredFeaturizationMethodTypeDef = TypedDict(
 _OptionalFeaturizationMethodTypeDef = TypedDict(
     "_OptionalFeaturizationMethodTypeDef",
     {
-        "FeaturizationMethodParameters": Dict[str, str],
+        "FeaturizationMethodParameters": Mapping[str, str],
     },
     total=False,
 )
@@ -775,7 +780,7 @@ _RequiredFeaturizationTypeDef = TypedDict(
 _OptionalFeaturizationTypeDef = TypedDict(
     "_OptionalFeaturizationTypeDef",
     {
-        "FeaturizationPipeline": List["FeaturizationMethodTypeDef"],
+        "FeaturizationPipeline": Sequence["FeaturizationMethodTypeDef"],
     },
     total=False,
 )
@@ -835,6 +840,7 @@ GetAccuracyMetricsResponseTypeDef = TypedDict(
     {
         "PredictorEvaluationResults": List["EvaluationResultTypeDef"],
         "AutoMLOverrideStrategy": Literal["LatencyOptimized"],
+        "OptimizationMetric": OptimizationMetricType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -856,7 +862,7 @@ _RequiredInputDataConfigTypeDef = TypedDict(
 _OptionalInputDataConfigTypeDef = TypedDict(
     "_OptionalInputDataConfigTypeDef",
     {
-        "SupplementaryFeatures": List["SupplementaryFeatureTypeDef"],
+        "SupplementaryFeatures": Sequence["SupplementaryFeatureTypeDef"],
     },
     total=False,
 )
@@ -912,7 +918,7 @@ ListDatasetImportJobsRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -949,7 +955,7 @@ ListForecastExportJobsRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -968,7 +974,7 @@ ListForecastsRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -987,7 +993,7 @@ ListPredictorBacktestExportJobsRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1006,7 +1012,7 @@ ListPredictorsRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1041,6 +1047,7 @@ MetricsTypeDef = TypedDict(
         "RMSE": float,
         "WeightedQuantileLosses": List["WeightedQuantileLossTypeDef"],
         "ErrorMetrics": List["ErrorMetricTypeDef"],
+        "AverageWeightedQuantileLoss": float,
     },
     total=False,
 )
@@ -1058,9 +1065,9 @@ PaginatorConfigTypeDef = TypedDict(
 ParameterRangesTypeDef = TypedDict(
     "ParameterRangesTypeDef",
     {
-        "CategoricalParameterRanges": List["CategoricalParameterRangeTypeDef"],
-        "ContinuousParameterRanges": List["ContinuousParameterRangeTypeDef"],
-        "IntegerParameterRanges": List["IntegerParameterRangeTypeDef"],
+        "CategoricalParameterRanges": Sequence["CategoricalParameterRangeTypeDef"],
+        "ContinuousParameterRanges": Sequence["ContinuousParameterRangeTypeDef"],
+        "IntegerParameterRanges": Sequence["IntegerParameterRangeTypeDef"],
     },
     total=False,
 )
@@ -1153,7 +1160,7 @@ SchemaAttributeTypeDef = TypedDict(
 SchemaTypeDef = TypedDict(
     "SchemaTypeDef",
     {
-        "Attributes": List["SchemaAttributeTypeDef"],
+        "Attributes": Sequence["SchemaAttributeTypeDef"],
     },
     total=False,
 )
@@ -1196,7 +1203,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1223,7 +1230,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1231,7 +1238,7 @@ UpdateDatasetGroupRequestRequestTypeDef = TypedDict(
     "UpdateDatasetGroupRequestRequestTypeDef",
     {
         "DatasetGroupArn": str,
-        "DatasetArns": List[str],
+        "DatasetArns": Sequence[str],
     },
 )
 
